# coding: utf-8

"""
Hive AI API

API for Hive AI model training and evaluation

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Target(str, Enum):
    """
    All existing targets. Some might no be available in the latest data version, but kept for older versions.
    """

    """
    allowed enum values
    """
    TATOOINE = "Tatooine"
    ALDERAAN = "Alderaan"
    HOTH = "Hoth"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Target from a JSON string"""
        return cls(json.loads(json_str))
