# coding: utf-8

"""
Marketcap Service API

API for retrieving historical marketcap data, available exchanges, and indicators.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TimeInterval(str, Enum):
    """
    TimeInterval
    """

    """
    allowed enum values
    """
    ENUM_15M = "15m"
    ENUM_30M = "30m"
    ENUM_1H = "1h"
    ENUM_4H = "4h"
    ENUM_1D = "1d"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TimeInterval from a JSON string"""
        return cls(json.loads(json_str))
